@@ -23,6 +23,7 @@ _B = TypeVar("_B")
 @dataclass(frozen=True)
 class Cmd(Generic[_A]):
     # Equivalent to haskell IO type
+    # unsafe_unwrap not included as method for discouraging its use
     _value: Patch[Callable[[], _A]]
 
     @staticmethod
@@ -48,14 +49,37 @@ class Cmd(Generic[_A]):
         return self.bind(lambda _: other)
 
 
+@dataclass(frozen=True)
+class _CmdUnwrapper:
+    pass
+
+
+@dataclass(frozen=True)
+class CmdUnwrapper:
+    # Do not build any public constructors or instances
+    # This obj is only accessible in the action context through the `new_cmd` builder
+    _inner: _CmdUnwrapper
+
+    @staticmethod
+    def unwrap(action: Cmd[_A]) -> _A:
+        return action._value.unwrap()
+
+
+_unwrapper = CmdUnwrapper(_CmdUnwrapper())
+
+
+def new_cmd(action: Callable[[CmdUnwrapper], _A]) -> Cmd[_A]:
+    return Cmd(Patch(lambda: action(_unwrapper)))
+
+
 def unsafe_unwrap(action: Cmd[_A]) -> _A:
     # This is an unsafe constructor (type-check cannot ensure its proper use)
     # Do not use until is strictly necessary
     # WARNING: this is equivalent to compute, and will execute the Cmd
     #
-    # Some use cases:
-    # - When all actions (Cmd[_A]) result in the same output instance (_A)
-    # and side effects are not present or negligible, this unwrap can be used
-    # - When defining a new Cmd at the cmd context (the cmd lambda function),
-    # this ensures that execution is done in the compute phase
+    # Only use when all actions (Cmd[_A]) result in the same output instance (_A)
+    # and side effects are not present or negligible.
+    # e.g. unwrap a cmd when used on a cached function definition
+    #
+    # [NOTICE] Do not use this function for defining a new Cmd, use `new_cmd` instead
     return action._value.unwrap()
