@@ -32,7 +32,7 @@ PrimitiveTypesList = (
     bool,
     type(None),
 )
-PrimitiveTVar = TypeVar(
+PrimitiveTVar = TypeVar(  # Deprecated use NotNonePrimTvar instead
     "PrimitiveTVar", str, int, float, Decimal, bool, Type[None]
 )
 NotNonePrimTvar = TypeVar("NotNonePrimTvar", str, int, float, Decimal, bool)
