@@ -6,7 +6,6 @@ from fa_purity.json.errors.invalid_type import (
 )
 from fa_purity.json.primitive.core import (
     NotNonePrimTvar,
-    PrimitiveTVar,
 )
 from fa_purity.result import (
     Result,
@@ -21,8 +20,8 @@ _T = TypeVar("_T")
 
 
 def to_primitive(
-    raw: _T, prim_type: Type[PrimitiveTVar]
-) -> Result[PrimitiveTVar, InvalidType]:
+    raw: _T, prim_type: Type[NotNonePrimTvar]
+) -> Result[NotNonePrimTvar, InvalidType]:
     if isinstance(raw, prim_type):
         return Result.success(raw)
     return Result.failure(
