@@ -11,6 +11,10 @@ from fa_purity import (
 from fa_purity.cmd import (
     Cmd,
 )
+from fa_purity.cmd.core import (
+    CmdUnwrapper,
+    new_cmd,
+)
 from fa_purity.frozen import (
     FrozenList,
 )
@@ -51,6 +55,15 @@ class Stream(_Stream[_T]):
             lambda i: functools.reduce(function, i, init)
         )
 
+    def bind(self, function: Callable[[_T], Stream[_R]]) -> Stream[_R]:
+        def _action(act: CmdUnwrapper) -> Iterable[_R]:
+            items = act.unwrap(self.map(function)._new_iter)
+            unchained = iter(act.unwrap(i._new_iter) for i in items)
+            return _iter_factory.chain(unchained)
+
+        draft: _Stream[_R] = _Stream(new_cmd(_action))
+        return Stream(draft)
+
     def filter(self, function: Callable[[_T], bool]) -> Stream[_T]:
         draft = _Stream(
             self._new_iter.map(lambda i: iter(filter(function, i)))
