@@ -5,6 +5,10 @@ from fa_purity.cmd import (
     Cmd,
     unsafe_unwrap,
 )
+from fa_purity.cmd.core import (
+    CmdUnwrapper,
+    new_cmd,
+)
 from fa_purity.maybe import (
     Maybe,
 )
@@ -16,20 +20,41 @@ from fa_purity.stream.core import (
     Stream,
 )
 from typing import (
+    Iterable,
     Optional,
     TypeVar,
+    Union,
 )
 
 _T = TypeVar("_T")
 
 
-def chain(
+def _chain_1(
     unchained: Stream[PureIter[_T]],
 ) -> Stream[_T]:
     draft = _Stream(unchained.unsafe_to_iter().map(_iter_factory.chain))
     return Stream(draft)
 
 
+def _chain_2(
+    unchained: PureIter[Stream[_T]],
+) -> Stream[_T]:
+    def _action(act: CmdUnwrapper) -> Iterable[_T]:
+        iters = (act.unwrap(i.unsafe_to_iter()) for i in unchained)
+        return _iter_factory.chain(iters)
+
+    draft = _Stream(new_cmd(_action))
+    return Stream(draft)
+
+
+def chain(
+    unchained: Union[Stream[PureIter[_T]], PureIter[Stream[_T]]],
+) -> Stream[_T]:
+    if isinstance(unchained, Stream):
+        return _chain_1(unchained)
+    return _chain_2(unchained)
+
+
 def squash(stm: Stream[Cmd[_T]]) -> Stream[_T]:
     draft = _Stream(stm.unsafe_to_iter().map(_iter_factory.squash))
     return Stream(draft)
